@@ -4,18 +4,18 @@ renv_parallel_cores <- function() {
   if (renv_platform_windows())
     return(1L)
 
-  config <- renv_config("updates.parallel", default = TRUE)
+  value <- config$updates.parallel()
   case(
-    identical(config, TRUE)  ~ getOption("mc.cores", default = 2L),
-    identical(config, FALSE) ~ 1L,
-    ~ as.integer(config)
+    identical(value, TRUE)  ~ getOption("mc.cores", default = 2L),
+    identical(value, FALSE) ~ 1L,
+    ~ as.integer(value)
   )
 
 }
 
 renv_parallel_exec <- function(data, callback) {
   cores <- renv_parallel_cores()
-  if (renv_config("updates.parallel", default = TRUE))
+  if (config$updates.parallel())
     parallel::mclapply(data, callback, mc.cores = cores)
   else
     lapply(data, callback)
