@@ -160,9 +160,11 @@ update <- function(packages = NULL,
   renv_scope_error_handler()
   renv_dots_check(...)
 
-  # get package records
   project <- renv_project_resolve(project)
-  library <- library %||% renv_libpaths_all()
+  renv_scope_lock(project = project)
+
+  # get package records
+  library <- renv_path_normalize(library %||% renv_libpaths_all())
   records <- renv_snapshot_r_packages(library = library, project = project)
   packages <- packages %||% setdiff(names(records), settings$ignored.packages(project = project))
 
