@@ -253,3 +253,13 @@ test_that(".renvignore can be used to ignore all but certain files", {
   expect_false("oatmeal" %in% deps$Package)
 
 })
+
+test_that("exercise chunks are ignored", {
+  deps <- renv::dependencies("resources/learnr-exercise.Rmd")
+  expect_true("A" %in% deps$Package)
+})
+
+test_that("dependencies in R functions can be found", {
+  deps <- renv::dependencies(function() bread::bread())
+  expect_true("bread" %in% deps$Package)
+})
